#!/usr/bin/python
from Foundation import NSNumber
from AppKit import NSImage
from QTKit import *

class QuickTimeError(Exception):
    @classmethod
    def from_nserror(cls, nserror):
        return cls(nserror.userInfo()['NSLocalizedDescription'])

def createQT(infiles, sequence, durations, outfile):
    attrs = {QTAddImageCodecType: 'avc1', QTAddImageCodecQuality: NSNumber.numberWithLong_(codecHighQuality)}
    mov, err = QTMovie.alloc().initToWritableFile_error_(outfile, None)
    if mov is None:
        raise QuickTimeError.from_nserror(err)
    n = len(durations)-1
    i = 0
    for index in sequence:
        img = NSImage.alloc().initWithContentsOfFile_(infiles[sequence[index]])
        t = durations[i]
        if i<n:
            i = i+1
        else:
            i = 0
        time = QTMakeTime(t, 600)
        mov.addImage_forDuration_withAttributes_(img, time, attrs)
    mov.updateMovieFile()

if __name__ == '__main__':
    import os,sys,csv,string

    buildfile = sys.argv[1]
    framedata = csv.reader(open(buildfile, 'rb'), delimiter=' ')
    imagefiles = []
    durations = []
    for row in framedata:
        if os.path.exists(row[0]):
            imagefiles.append(row[0])
            if len(row)>1:
                durations.append(float(row[1]))
            else:
                durations.append(30)
        else:
            print row[0]+': File not found'
    if len(imagefiles)==0:
        print 'No images found. Movie not created'
    else:
        print 'Creating movie from frames:'
        print '\n'.join(imagefiles)
        outfileName = os.path.abspath(sys.argv[2])
        createQT(imagefiles, range(len(durations)), durations, outfileName)
    
